@@ -1,6 +1,5 @@
-use anyhow::Result;
-use async_trait::async_trait;
-
+use futuresdr::anyhow::Result;
+use futuresdr::async_trait::async_trait;
 use futuresdr::runtime::AsyncKernel;
 use futuresdr::runtime::Block;
 use futuresdr::runtime::BlockMeta;
