@@ -1,7 +1,7 @@
-use anyhow::Result;
 use std::cmp;
 use std::ptr;
 
+use crate::anyhow::Result;
 use crate::runtime::AsyncKernel;
 use crate::runtime::Block;
 use crate::runtime::BlockMeta;
