@@ -1,4 +1,3 @@
-use anyhow::{Context, Result};
 #[cfg(not(target_arch = "wasm32"))]
 use async_io::block_on;
 #[cfg(not(target_arch = "wasm32"))]
@@ -15,6 +14,7 @@ use wasm_rs_async_executor::single_threaded::block_on;
 #[cfg(target_arch = "wasm32")]
 type Task<T> = single_threaded::TaskHandle<T>;
 
+use crate::anyhow::{Context, Result};
 use crate::runtime::config;
 #[cfg(not(target_arch = "wasm32"))]
 use crate::runtime::ctrl_port;
@@ -29,12 +29,16 @@ use crate::runtime::Flowgraph;
 use crate::runtime::FlowgraphHandle;
 use crate::runtime::WorkIo;
 
-pub struct Runtime<S: Scheduler> {
+/// This is the [Runtime] that runs a [Flowgraph] to completion.
+///
+/// [Runtime]s are generic over the scheduler used to run the [Flowgraph].
+pub struct Runtime<S> {
     scheduler: S,
 }
 
 #[cfg(not(target_arch = "wasm32"))]
 impl Runtime<SmolScheduler> {
+    /// Constructs a new [Runtime] using [SmolScheduler::default()] for the [Scheduler].
     pub fn new() -> Runtime<SmolScheduler> {
         RuntimeBuilder {
             scheduler: SmolScheduler::default(),
@@ -68,8 +72,9 @@ impl Default for Runtime<WasmScheduler> {
 }
 
 impl<S: Scheduler> Runtime<S> {
-    pub fn custom(scheduler: S) -> RuntimeBuilder<S> {
-        RuntimeBuilder { scheduler }
+    /// Create a [Runtime] with a given [Scheduler]
+    pub fn with_scheduler(scheduler: S) -> Runtime<S> {
+        RuntimeBuilder { scheduler }.build()
     }
 
     pub fn spawn<T: Send + 'static>(
@@ -115,6 +120,7 @@ impl<S: Scheduler> Runtime<S> {
         (task, FlowgraphHandle::new(fg_inbox))
     }
 
+    /// Main method that kicks-off the running of a [Flowgraph].
     #[cfg(not(target_arch = "wasm32"))]
     pub fn run(&self, fg: Flowgraph) -> Result<Flowgraph> {
         let (handle, _) = self.start(fg);
@@ -128,7 +134,7 @@ impl<S: Scheduler> Runtime<S> {
     }
 }
 
-pub struct RuntimeBuilder<S: Scheduler> {
+pub struct RuntimeBuilder<S> {
     scheduler: S,
 }
 
